# Candango Cartola

[![Latest PyPI version](https://img.shields.io/pypi/v/cartola.svg)](https://pypi.org/project/cartola/)
[![Number of PyPI downloads](https://img.shields.io/pypi/dm/cartola.svg)](https://pypi.org/project/cartola/#files)
[![Build Status](https://img.shields.io/endpoint.svg?url=https%3A%2F%2Factions-badge.atrox.dev%2Fcandango%2Fcartola%2Fbadge&style=flat)](https://actions-badge.atrox.dev/candango/cartola/goto)
[![GitHub license](https://img.shields.io/github/license/candango/firenado)](https://github.com/candango/cartola/blob/develop/LICENSE)

Candango's Shared Utilities.

Cartola means Top Hat. You see? A magician gets a rabbit from a Top Hat, right?
Right? I think you got the joke...

I'm pretty creative. ;)

We just needed a namespace to share some util modules, that's a great one.

## License

**Apache License V2.0**

Copyright © 2015-2025 Flavio Garcia
